<?php

namespace apexl\Io\modules\product\entities;

use apexl\Io\includes\Entity;
use apexl\Io\includes\System;
use apexl\Io\modules\product\entities\operators\productOperator;

class productEntity extends Entity{


    public function __construct()
    {
        parent::__construct('product');
        $this->setOperator(new productOperator('product'));
    }
}