<?php

namespace apexl\Io\modules\product\services;

use apexl\Config\Singleton;
use apexl\Io\includes\Routes;
use apexl\Io\includes\System;
use apexl\Io\modules\payment\entities\invoiceEntity;
use apexl\Io\modules\payment\entities\paymentEntity;
use apexl\Io\modules\payment\entities\userCreditEntity;
use apexl\Io\modules\payment\providers\stripeProvider;
use apexl\Io\modules\payment\services\cardValidationService;
use apexl\Io\modules\payment\services\paymentService;
use apexl\Io\modules\product\entities\productEntity;
use apexl\Io\modules\subscription\entities\subscriptionCreditEntity;
use apexl\Io\modules\subscription\entities\subscriptionEntity;
use apexl\Io\modules\user\entities\userEntity;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class productService {

    protected $config;

    public function __construct()
    {
        $this->config = Singleton::getInstance();
    }

}