<?php

namespace apexl\Io\modules\userDisplay\forms;

use apexl\Io\includes\Routes;
use apexl\Io\modules\formbuilder\entities\formEntity;
use apexl\Io\modules\formbuilder\includes\inputField;
use apexl\Io\modules\formbuilder\includes\linkField;

class editProductForm {

    public function editProductForm() {
        $form = new formEntity();
        $form->setId('editProduct');
        $form->setMethod('post');
        $form->setActionUrl(Routes::getRoutePattern('product.editProduct'));


        //$form->addField((new inputField('email'))->setLabel('Email Address')->setInputType('email')->isRequired());
        //$form->addField((new linkField('returnToLogin'))->setLinkType('internal')->addClass('forgottenPasswordLink')->setValue('/login')->setLinkTitle('Return to login'));

        return $form->getBuiltFormArray();
    }
}