<?php

namespace apexl\Io\modules\productDisplay\components;

use apexl\Io\includes\Routes;
use apexl\Io\modules\display\components\LinkTile;
use apexl\Io\modules\display\components\RowWrapper;
use apexl\Io\services\pathUtility;

class primaryButtons extends RowWrapper {

    public function __construct()
    {
        parent::__construct();
        $this->setName('RowWrapper');
        $path = pathUtility::getInstance();
        $currentRouteName = $path->getCurrentRouteName();
        $this->addComponent(
            (new LinkTile())
                ->setName('LinkTile')
                ->setColWidth('md', 4)
                ->addText('Create Product')
                ->addIcon('boxes-alt')
                ->addRoute(Routes::getRoutePattern('product.display.post'))
        );
    }
}